@@ -25,20 +25,27 @@
 #' @param xcol name of the column with the categorical factor to be plotted on X axis.
 #' @param ycol name of the column with quantitative variable to plot on the Y axis.
 #' @param shapes name of the column with the second categorical factor, for example from a two-way ANOVA design.
-#' @param ewid width of error bars, default set to 0.2.
+#' @param facet add another variable from the data table to create faceted graphs using \code{ggplot2}[facet_wrap].
 #' @param symsize size of symbols, default set to 3.
-#' @param symthick size of outline of symbol lines (\code{stroke = 1.5}), default set to 1.5
-#' @param jitter extent of jitter (scatter) of symbols, default is 0.2. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
+#' @param s_alpha fractional opacity of symbols, default set to 0.8 (i.e. 80% opacity). Set `s_alpha = 0` to not show scatter plot.
+#' @param b_alpha fractional opacity of boxes.  Default is set to 0, which results in white boxes inside violins. Change to any value >0 up to 1 for different levels of transparency. 
+#' @param jitter extent of jitter (scatter) of symbols, default is 0.1. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
+#' @param ewid width of error bars, default set to 0.2.
+#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
+#' @param LogYTrans transform Y axis into "log10" or "log2"
+#' @param LogYBreaks argument for \code{ggplot2[scale_y_continuous]} for Y axis breaks on log scales, default is `waiver()`, or provide a vector of desired breaks.
+#' @param LogYLabels argument for \code{ggplot2[scale_y_continuous]} for Y axis labels on log scales, default is `waiver()`, or provide a vector of desired labels. 
+#' @param LogYLimits a vector of length two specifying the range (minimum and maximum) of the Y axis.
+#' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
 #' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
-#' @param b_alpha fractional opacity of bars, default set to 1 (i.e. maximum opacity & zero transparency).
-#' @param s_alpha fractional opacity of symbols, default set to 1 (i.e. maximum opacity & zero transparency).
-#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
+#' @param symthick size (in 'pt' units) of outline of symbol lines (\code{stroke}), default = `fontsize`/22.
+#' @param bthick thickness (in 'pt' units) of lines of boxes; default = `fontsize`/22.
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
+#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
 #' @param SingleColour a colour hexcode (starting with #), a number between 1-154, or names of colours from `grafify` colour palettes to fill along X-axis aesthetic. Accepts any colour other than "black"; use `grey_lin11`, which is almost black.
-#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
-#'
-#' @param ... any additional arguments to pass to \code{ggplot2}[geom_boxplot] or \code{ggplot2}[geom_point].
+#' @param ... any additional arguments to pass.
+#' 
 #' @return This function returns a \code{ggplot2} object of class "gg" and "ggplot".
 #' @export plot_3d_scatterbar
 #' @import ggplot2 Hmisc
@@ -70,26 +77,28 @@
 #' bars = Treatment, 
 #' shapes = Block)
 #' 
-plot_3d_scatterbar <- function(data, xcol, ycol, shapes, ewid = 0.2, symsize = 2.5, symthick = 1, jitter = 0.2, fontsize = 20, b_alpha = 1.0, s_alpha = 1, ColSeq = TRUE, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColRev = FALSE, SingleColour = "NULL", TextXAngle = 0, ...){
+plot_3d_scatterbar <- function(data, xcol, ycol, shapes, facet, symsize = 3, s_alpha = 0.8, b_alpha = 1, jitter = 0.1, ewid = 0.2, TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
   ColPal <- match.arg(ColPal)
+  if (missing(bthick)) {bthick = fontsize/22}
+  if (missing(symthick)) {symthick = fontsize/22}
   if (missing(SingleColour)) {
     P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                    y = {{ ycol }},
                                    group = factor({{ xcol }})))+
       stat_summary(geom = "bar", width = .7, colour = "black",
-                   fun = "mean", size = 1,
+                   fun = "mean", size = bthick,
                    aes(fill = factor({{ xcol }})),
-                   alpha = {{ b_alpha }},
+                   alpha = b_alpha,
                    position = position_dodge(width = 0.8))+
-      geom_point(size = {{ symsize }}, 
-                 stroke = {{ symthick }},
-                 alpha = {{ s_alpha }}, 
+      geom_point(size = symsize, 
+                 stroke = symthick,
+                 alpha = s_alpha, 
                  colour = "black",
                  position = position_jitterdodge(dodge.width = 0.8,
-                                                 jitter.width = {{ jitter }}),
+                                                 jitter.width = jitter),
                  aes(shape = factor({{ shapes }})))+
-      stat_summary(geom = "errorbar", width = {{ ewid }},
-                   fun.data = "mean_sdl", size = 1,
+      stat_summary(geom = "errorbar", width = ewid,
+                   fun.data = "mean_sdl", size = bthick,
                    fun.args = list(mult = 1),
                    position = position_dodge(width = 0.8),
                    ...)+
@@ -97,47 +106,75 @@ plot_3d_scatterbar <- function(data, xcol, ycol, shapes, ewid = 0.2, symsize = 2
       labs(x = enquo(xcol),
            fill = enquo(xcol),
            shape = enquo(shapes))+
-      theme_classic(base_size = {{ fontsize }})+
-      theme(strip.background = element_blank())+
-      guides(x = guide_axis(angle = {{ TextXAngle }}),
-             fill = guide_legend(order = 1),
-             shape = guide_legend(order = 2))+
-      scale_fill_grafify(palette = {{ ColPal }},
-                         reverse = {{ ColRev }},
-                         ColSeq = {{ ColSeq }})
+      scale_fill_grafify(palette = ColPal,
+                         reverse = ColRev,
+                         ColSeq = ColSeq)
   } else {
     ifelse(grepl("#", SingleColour), 
            a <- SingleColour,
-           a <- get_graf_colours({{ SingleColour }}))
+           a <- get_graf_colours(SingleColour))
     P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                    y = {{ ycol }},
                                    group = factor({{ xcol }})))+
       stat_summary(geom = "bar", width = .7, colour = "black",
-                   fun = "mean", size = 1,
+                   fun = "mean", size = bthick,
                    fill = a,
-                   alpha = {{ b_alpha }},
+                   alpha = b_alpha,
                    position = position_dodge(width = 0.8),
                    ...)+
-      geom_point(size = {{ symsize }}, 
-                 stroke = {{ symthick }},
-                 alpha = {{ s_alpha }}, 
+      geom_point(size = symsize, 
+                 stroke = symthick,
+                 alpha = s_alpha, 
                  colour = "black",
                  position = position_jitterdodge(dodge.width = 0.8,
-                                                 jitter.width = {{ jitter }}),
+                                                 jitter.width = jitter),
                  aes(shape = factor({{ shapes }})))+
-      stat_summary(geom = "errorbar", width = {{ ewid }},
-                   fun.data = "mean_sdl", size = 1,
+      stat_summary(geom = "errorbar", width = ewid,
+                   fun.data = "mean_sdl", size = bthick,
                    fun.args = list(mult = 1),
                    position = position_dodge(width = 0.8),
                    ...)+
       scale_shape_manual(values = 0:25)+
       labs(x = enquo(xcol),
-           shape = enquo(shapes))+
-      theme_classic(base_size = {{ fontsize }})+
-      theme(strip.background = element_blank())+
-      guides(x = guide_axis(angle = {{ TextXAngle }}),
-             fill = guide_legend(order = 1),
-             shape = guide_legend(order = 2))
+           shape = enquo(shapes))
   }
+  if(!missing(facet)) {
+    P <- P + facet_wrap(vars({{ facet }}), 
+                        scales = facet_scales, 
+                        ...)
+  }
+  if (!missing(LogYTrans)) {
+    if (!(LogYTrans %in% c("log2", "log10"))) {
+      stop("LogYTrans only allows 'log2' or 'log10' transformation.")
+    }
+    if (LogYTrans == "log10") {
+      P <- P + 
+        scale_y_continuous(trans = "log10", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels,
+                           limits = LogYLimits,
+                           ...)+
+        annotation_logticks(sides = "l", 
+                            outside = TRUE,
+                            base = 10,
+                            long = unit(0.2, "cm"), 
+                            mid = unit(0.1, "cm"),
+                            ...)+ 
+        coord_cartesian(clip = "off", ...)
+    }
+    if (LogYTrans == "log2") {
+      P <- P + 
+        scale_y_continuous(trans = "log2", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels,
+                           limits = LogYLimits,
+                           ...)}
+  }
+  P <- P+
+    theme_classic(base_size = fontsize)+
+    theme(strip.background = element_blank())+
+    guides(x = guide_axis(angle = TextXAngle),
+           fill = guide_legend(order = 1),
+           shape = guide_legend(order = 2))
   P
 }
