@@ -25,26 +25,29 @@
 #' @param xcol name of the column with the categorical factor to be plotted on X axis. If your table has numeric X, enter \code{xcol = factor(name of colum)}.
 #' @param ycol name of the column with quantitative variable to plot on the Y axis.
 #' @param shapes name of the column with the second categorical factor in a two-way ANOVA design.
+#' @param facet add another variable from the data table to create faceted graphs using \code{ggplot2}[facet_wrap].
 #' @param symsize size of symbols, default set to 3.
-#' @param symthick size of outline of symbol lines (\code{stroke = 1.0}), default set to 1.0.
-#' @param jitter extent of jitter (scatter) of symbols, default is 0.2. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
-#' @param bvthick thickness of both violin and boxplot lines; default 1.
-#' @param bwid width of boxplots; default 0.2
-#' @param b_alpha fractional opacity of boxplots.  Default is set to 0, which results in white boxes inside violins. Change to any value >0 up to 1 for different levels of transparency. 
-#' @param v_alpha fractional opacity of violins, default set to 1 (i.e. maximum opacity & zero transparency).
-#' @param s_alpha fractional opacity of symbols, default set to 1 (i.e. maximum opacity & zero transparency). Set `s_alpha = 0` to not show scatter plot.
-#' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
-#' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
-#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
-#' @param jitter extent of jitter (scatter) of symbols, default is 0 (i.e. aligned symbols). To reduce symbol overlap, try 0.1-0.3 or higher.  
-#' @param trim set whether tips of violin plot should be trimmed at high/low data. Default \code{trim = T}, can be changed to F.
-#' @param scale set to "area" by default, can be changed to "count" or "width".
-#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
-#' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
-#' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
-#' @param SingleColour a colour hexcode (starting with #), a number between 1-154, or names of colours from `grafify` colour palettes to fill along X-axis aesthetic. Accepts any colour other than "black"; use `grey_lin11`, which is almost black.
+#' @param s_alpha fractional opacity of symbols, default set to 0.8 (i.e. 80% opacity). Set `s_alpha = 0` to not show scatter plot.
+#' @param b_alpha fractional opacity of boxes.  Default is set to 0, which results in white boxes inside violins. Change to any value >0 up to 1 for different levels of transparency. 
+#' @param v_alpha fractional opacity of violins, default set to 1.
+#' @param bwid width of boxes (default 0.3).
+#' @param vadjust number to adjust the smooth/wigglyness of violin plot (default is 1).
+#' @param jitter extent of jitter (scatter) of symbols, default is 0.1. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
 #' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
+#' @param scale set to "area" by default, can be changed to "count" or "width".
+#' @param trim set whether tips of violin plot should be trimmed at high/low data. Default \code{trim = T}, can be changed to F.
+#' @param LogYTrans transform Y axis into "log10" or "log2"
+#' @param LogYBreaks argument for \code{ggplot2[scale_y_continuous]} for Y axis breaks on log scales, default is `waiver()`, or provide a vector of desired breaks.
+#' @param LogYLabels argument for \code{ggplot2[scale_y_continuous]} for Y axis labels on log scales, default is `waiver()`, or provide a vector of desired labels. 
+#' @param LogYLimits a vector of length two specifying the range (minimum and maximum) of the Y axis.
+#' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
 #' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
+#' @param symthick size (in 'pt' units) of outline of symbol lines (\code{stroke}), default = `fontsize`/22.
+#' @param bvthick thickness (in 'pt' units) of both violin and boxplot lines; default = `fontsize`/22.
+#' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
+#' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
+#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
+#' @param SingleColour a colour hexcode (starting with #), a number between 1-154, or names of colours from `grafify` colour palettes to fill along X-axis aesthetic. Accepts any colour other than "black"; use `grey_lin11`, which is almost black.
 #' @param ... any additional arguments to pass to \code{ggplot2}[geom_boxplot] or \code{ggplot2}[geom_violin].
 #'
 #' @return This function returns a \code{ggplot2} object of class "gg" and "ggplot".
@@ -72,151 +75,175 @@
 #' boxes = Time, 
 #' shapes = Experiment)
 #' 
-plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, symsize = 2.5, s_alpha = 1, symthick = 1.0, v_alpha = 1, b_alpha = 0, bwid = 0.2, bvthick = 1, jitter = 0.2, fontsize = 20, ColSeq = TRUE, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColRev = FALSE, SingleColour = "NULL", TextXAngle = 0, scale = "width", trim = TRUE, ...){
+plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, facet, symsize = 3, s_alpha = 0.8, b_alpha = 0, v_alpha = 1, bwid = 0.3, vadjust = 1, jitter = 0.1,  TextXAngle = 0, scale = "width", trim = TRUE, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bvthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
   ColPal <- match.arg(ColPal)
+  if (missing(symthick)) {symthick = fontsize/22}
+  if(missing(bvthick)) {bvthick = fontsize/22}
   if (missing(SingleColour)) {
     if (b_alpha == 0){
       P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                      y = {{ ycol }},
                                      group = factor({{ xcol }})))+
         geom_violin(aes(fill = factor({{ xcol }})),
-                    size = {{ bvthick }},
-                    alpha = {{ v_alpha }},
-                    scale = {{ scale }},
+                    size = bvthick,
+                    alpha = v_alpha,
+                    scale = scale,
                     position = position_dodge(width = 0.8),
                     colour = "black",
-                    trim = {{ trim }}, ...)+
+                    adjust = vadjust,
+                    trim = trim, ...)+
         geom_boxplot(aes(fill = factor({{ xcol }})), 
                      fill = "white",
-                     size = {{ bvthick }},
+                     size = bvthick,
                      position = position_dodge(width = 0.8),
-                     width = {{ bwid }},
+                     width = bwid,
                      outlier.alpha = 0, 
                      colour = "black",
                      ...)+
-        geom_point(size = {{ symsize }}, 
-                   stroke = {{ symthick }},
-                   alpha = {{ s_alpha }}, 
+        geom_point(size = symsize, 
+                   stroke = symthick,
+                   alpha = s_alpha, 
                    colour = "black",
-                   position = position_jitterdodge(jitter.width = {{ jitter }},
+                   position = position_jitterdodge(jitter.width = jitter,
                                                    dodge.width = 0.8),
                    aes(shape = factor({{ shapes }})))+
         scale_shape_manual(values = 0:25)+
         labs(x = enquo(xcol),
              fill = enquo(xcol),
-             shape = enquo(shapes))+
-        theme_classic(base_size = {{ fontsize }})+
-        theme(strip.background = element_blank())+
-        guides(x = guide_axis(angle = {{ TextXAngle }}),
-               fill = guide_legend(order = 1),
-               shape = guide_legend(order = 2))
+             shape = enquo(shapes))
     } else {
       P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                      y = {{ ycol }},
                                      group = factor({{ xcol }})))+
         geom_violin(aes(fill = factor({{ xcol }})),
-                    size = {{ bvthick }},
-                    alpha = {{ v_alpha }},
-                    scale = {{ scale }},
+                    size = bvthick,
+                    alpha = v_alpha,
+                    scale = scale,
                     position = position_dodge(width = 0.8),
                     colour = "black", 
-                    trim = {{ trim }}, ...)+
+                    adjust = vadjust,
+                    trim = trim, ...)+
         geom_boxplot(aes(fill = factor({{ xcol }})), 
-                     size = {{ bvthick }},
-                     alpha = {{ b_alpha }},
+                     size = bvthick,
+                     alpha = b_alpha,
                      position = position_dodge(width = 0.8),
-                     width = {{ bwid }},
+                     width = bwid,
                      outlier.alpha = 0, 
                      colour = "black",
                      ...)+
-        geom_point(size = {{ symsize }}, 
-                   stroke = {{ symthick }},
-                   alpha = {{ s_alpha }}, colour = "black",
-                   position = position_jitterdodge(jitter.width = {{ jitter }},
+        geom_point(size = symsize, 
+                   stroke = symthick,
+                   alpha = s_alpha, colour = "black",
+                   position = position_jitterdodge(jitter.width = jitter,
                                                    dodge.width = 0.8),
                    aes(shape = factor({{ shapes }})))+
         scale_shape_manual(values = 0:25)+
         labs(x = enquo(xcol),
              fill = enquo(xcol),
-             shape = enquo(shapes))+
-        theme_classic(base_size = {{ fontsize }})+
-        theme(strip.background = element_blank())+
-        guides(x = guide_axis(angle = {{ TextXAngle }}),
-               fill = guide_legend(order = 1),
-               shape = guide_legend(order = 2))
+             shape = enquo(shapes))
     }
-    P <- P + scale_fill_grafify(palette = {{ ColPal }}, 
-                                reverse = {{ ColRev }}, 
-                                ColSeq = {{ ColSeq }})
+    P <- P + scale_fill_grafify(palette = ColPal, 
+                                reverse = ColRev, 
+                                ColSeq = ColSeq)
   } else {
     ifelse(grepl("#", SingleColour), 
            a <- SingleColour,
-           a <- get_graf_colours({{ SingleColour }}))
+           a <- get_graf_colours(SingleColour))
     if (b_alpha == 0) {
       suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                                       y = {{ ycol }}))+
                          geom_violin(fill = a,
-                                     alpha = {{ v_alpha }},
-                                     trim = {{ trim }},
-                                     scale = {{ scale }},
+                                     alpha = v_alpha,
+                                     trim = trim,
+                                     scale = scale,
                                      colour = "black", 
-                                     size = {{ bvthick }},
+                                     size = bvthick,
+                                     adjust = vadjust,
                                      ...)+
                          geom_boxplot(fill = "white",
                                       colour = "black", 
-                                      size = {{ bvthick }},
+                                      size = bvthick,
                                       outlier.alpha = 0,
-                                      width = {{ bwid }},
+                                      width = bwid,
                                       ...)+
                          geom_point(aes(shape = factor({{ shapes }})),
-                                    position = position_jitter(width = {{ jitter }}),
-                                    alpha = {{ s_alpha }},
-                                    stroke = {{ symthick }},
-                                    size = {{ symsize }},
+                                    position = position_jitter(width = jitter),
+                                    alpha = s_alpha,
+                                    stroke = symthick,
+                                    size = symsize,
                                     fill = a,
                                     ...)+
                          scale_shape_manual(values = 0:25)+
                          labs(x = enquo(xcol),
-                              shape = enquo(shapes))+
-                         theme_classic(base_size = {{ fontsize }})+
-                         theme(strip.background = element_blank())+
-                         guides(x = guide_axis(angle = {{ TextXAngle }}),
-                                fill = guide_legend(order = 1),
-                                shape = guide_legend(order = 2)))
-                       } else {
-                         suppressWarnings(P <- ggplot2::ggplot(data, 
-                                                               aes(x = factor({{ xcol }}),
-                                                                   y = {{ ycol }}))+
-                                            geom_violin(fill = a,
-                                                        alpha = {{ v_alpha }},
-                                                        trim = {{ trim }},
-                                                        scale = {{ scale }},
-                                                        colour = "black", 
-                                                        size = {{ bvthick }},
-                                                        ...)+
-                                            geom_boxplot(fill = a,
-                                                         alpha = {{ b_alpha }},
-                                                         colour = "black", 
-                                                         size = {{ bvthick }},
-                                                         outlier.alpha = 0,
-                                                         width = {{ bwid }},
-                                                         ...)+
-                                            geom_point(aes(shape = factor({{ shapes }})),
-                                                       position = position_jitter(width = {{ jitter }}),
-                                                       alpha = {{ s_alpha }},
-                                                       stroke = {{ symthick }},
-                                                       size = {{ symsize }},
-                                                       fill = a,
-                                                       ...)+
-                                            scale_shape_manual(values = 0:25)+
-                                            labs(x = enquo(xcol),
-                                                 shape = enquo(shapes))+
-                                            theme_classic(base_size = {{ fontsize }})+
-                                            theme(strip.background = element_blank())+
-                                            guides(x = guide_axis(angle = {{ TextXAngle }}),
-                                                   fill = guide_legend(order = 1),
-                                                   shape = guide_legend(order = 2)))
-                                          }
-                       }
-  P
+                              shape = enquo(shapes)))
+    } else {
+      suppressWarnings(P <- ggplot2::ggplot(data, 
+                                            aes(x = factor({{ xcol }}),
+                                                y = {{ ycol }}))+
+                         geom_violin(fill = a,
+                                     alpha = v_alpha,
+                                     trim = trim,
+                                     scale = scale,
+                                     colour = "black", 
+                                     size = bvthick,
+                                     adjust = vadjust,
+                                     ...)+
+                         geom_boxplot(fill = a,
+                                      alpha = b_alpha,
+                                      colour = "black", 
+                                      size = bvthick,
+                                      outlier.alpha = 0,
+                                      width = bwid,
+                                      ...)+
+                         geom_point(aes(shape = factor({{ shapes }})),
+                                    position = position_jitter(width = jitter),
+                                    alpha = s_alpha,
+                                    stroke = symthick,
+                                    size = symsize,
+                                    fill = a,
+                                    ...)+
+                         scale_shape_manual(values = 0:25)+
+                         labs(x = enquo(xcol),
+                              shape = enquo(shapes)))
     }
+  }
+  if(!missing(facet)) {
+    P <- P + facet_wrap(vars({{ facet }}), 
+                        scales = facet_scales, 
+                        ...)
+  }
+  if (!missing(LogYTrans)) {
+    if (!(LogYTrans %in% c("log2", "log10"))) {
+      stop("LogYTrans only allows 'log2' or 'log10' transformation.")
+    }
+    if (LogYTrans == "log10") {
+      P <- P + 
+        scale_y_continuous(trans = "log10", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels,
+                           limits = LogYLimits, 
+                           ...)+
+        annotation_logticks(sides = "l", 
+                            outside = TRUE,
+                            base = 10,
+                            long = unit(0.2, "cm"), 
+                            mid = unit(0.1, "cm"),
+                            ...)+ 
+        coord_cartesian(clip = "off", ...)
+    }
+    if (LogYTrans == "log2") {
+      P <- P + 
+        scale_y_continuous(trans = "log2", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels, 
+                           limits = LogYLimits,
+                           ...)}
+  }
+  P <- P +
+    theme_classic(base_size = fontsize)+
+    theme(strip.background = element_blank())+
+    guides(x = guide_axis(angle = TextXAngle),
+           fill = guide_legend(order = 1),
+           shape = guide_legend(order = 2))
+  P
+}
