@@ -26,16 +26,24 @@
 #' @param ycol name of the column to plot on quantitative variable on the Y axis.
 #' @param boxes name of the column containing grouping within the factor plotted on X axis. Can be categorical or numeric X. If your table has numeric X and you want to plot as factor, enter \code{xcol = factor(name of colum)}.
 #' @param shapes name of the column that contains matched observations, e.g. subject IDs, experiment number etc.
+#' @param facet add another variable from the data table to create faceted graphs using \code{ggplot2}[facet_wrap].
 #' @param symsize size of symbols, default set to 3.
-#' @param symthick size of outline of symbol lines (\code{stroke = 1.0}), default set to 1.0.
-#' @param jitter extent of jitter (scatter) of symbols, default is 0.2. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
+#' @param s_alpha fractional opacity of symbols, default set to 0.8 (i.e. 80% opacity). Set `s_alpha = 0` to not show scatter plot.
+#' @param b_alpha fractional opacity of boxes.  Default is set to 0, which results in white boxes inside violins. Change to any value >0 up to 1 for different levels of transparency. 
+#' @param bwid width of boxes; default 0.5.
+#' @param jitter extent of jitter (scatter) of symbols, default is 0.1. Increase to reduce symbol overlap, set to 0 for aligned symbols.  
+#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
+#' @param LogYTrans transform Y axis into "log10" or "log2"
+#' @param LogYBreaks argument for \code{ggplot2[scale_y_continuous]} for Y axis breaks on log scales, default is `waiver()`, or provide a vector of desired breaks.
+#' @param LogYLabels argument for \code{ggplot2[scale_y_continuous]} for Y axis labels on log scales, default is `waiver()`, or provide a vector of desired labels. 
+#' @param LogYLimits a vector of length two specifying the range (minimum and maximum) of the Y axis.
+#' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
 #' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
-#' @param b_alpha fractional opacity of boxes, default set to 1 (i.e. maximum opacity & zero transparency).
-#' @param s_alpha fractional opacity of symbols, default set to 1 (i.e. maximum opacity & zero transparency).
-#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
+#' @param symthick size (in 'pt' units) of outline of symbol lines (\code{stroke}), default = `fontsize`/22.
+#' @param bthick thickness (in 'pt' units) of boxplot lines; default = `fontsize`/22.
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
-#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
+#' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
 #' @param ... any additional arguments to pass to \code{ggplot2}[geom_boxplot].
 #'
 #' @return This function returns a \code{ggplot2} object of class "gg" and "ggplot".
@@ -62,35 +70,72 @@
 #' bars = Treatment, 
 #' shapes = Block)
 
-plot_4d_scatterbox <- function(data, xcol, ycol, boxes, shapes, symsize = 2.5, symthick = 1.0, jitter = 0.2, fontsize = 20, b_alpha = 1, s_alpha = 1, ColSeq = TRUE, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColRev = FALSE, TextXAngle = 0, ...){
+plot_4d_scatterbox <- function(data, xcol, ycol, boxes, shapes, facet, symsize = 3, s_alpha = 0.8, b_alpha = 1, bwid = 0.5, jitter = 0.1, TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20,  symthick, bthick, ColPal = c("okabe_ito", "all_grafify", "bright", "contrast", "dark", "fishy", "kelly",  "light", "muted", "pale", "r4", "safe", "vibrant"), ColSeq = TRUE, ColRev = FALSE, ...){
   ColPal <- match.arg(ColPal)
+  if (missing(bthick)) {bthick = fontsize/22}
+  if (missing(symthick)) {symthick = fontsize/22}
   P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                            y = {{ ycol }},
-                            group = interaction(factor({{ boxes }}),
-                                                factor({{ xcol }}))))+
-    geom_boxplot(width = 0.5, alpha = {{ b_alpha }}, size = 1,
+                                 y = {{ ycol }},
+                                 group = interaction(factor({{ boxes }}),
+                                                     factor({{ xcol }}))))+
+    geom_boxplot(width = bwid, 
+                 alpha = b_alpha, 
+                 size = bthick,
                  aes(fill = factor({{ boxes }})), 
                  outlier.alpha = 0,
                  position = position_dodge(width = 0.8),
                  ...)+
-    geom_point(size = {{ symsize }}, 
-               alpha = {{ s_alpha }}, 
-               stroke = {{ symthick }}, 
+    geom_point(size = symsize, 
+               alpha = s_alpha, 
+               stroke = symthick, 
                colour = "black",
-               position = position_jitterdodge(jitter.width = {{ jitter }},
+               position = position_jitterdodge(jitter.width = jitter,
                                                dodge.width = 0.8),
                aes(shape = factor({{ shapes }})))+
     scale_shape_manual(values = 0:25)+
     labs(fill = enquo(boxes),
          x = enquo(xcol),
-         shape = enquo(shapes))+
-    theme_classic(base_size = {{ fontsize }})+
+         shape = enquo(shapes))
+  if(!missing(facet)) {
+    P <- P + facet_wrap(vars({{ facet }}), 
+                        scales = facet_scales, 
+                        ...)
+  }
+  if (!missing(LogYTrans)) {
+    if (!(LogYTrans %in% c("log2", "log10"))) {
+      stop("LogYTrans only allows 'log2' or 'log10' transformation.")
+    }
+    if (LogYTrans == "log10") {
+      P <- P + 
+        scale_y_continuous(trans = "log10", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels,
+                           limits = LogYLimits,
+                           ...)+
+        annotation_logticks(sides = "l", 
+                            outside = TRUE,
+                            base = 10,
+                            long = unit(0.2, "cm"), 
+                            mid = unit(0.1, "cm"),
+                            ...)+ 
+        coord_cartesian(clip = "off", ...)
+    }
+    if (LogYTrans == "log2") {
+      P <- P + 
+        scale_y_continuous(trans = "log2", 
+                           breaks = LogYBreaks, 
+                           labels = LogYLabels,
+                           limits = LogYLimits,
+                           ...)}
+  }
+  P <- P +
+    theme_classic(base_size = fontsize)+
     theme(strip.background = element_blank())+
-    guides(x = guide_axis(angle = {{ TextXAngle }}),
+    guides(x = guide_axis(angle = TextXAngle),
            fill = guide_legend(order = 1),
            shape = guide_legend(order = 2))+
-    scale_fill_grafify(palette = {{ ColPal }}, 
-                       reverse = {{ ColRev }}, 
-                       ColSeq = {{ ColSeq }})
+    scale_fill_grafify(palette = ColPal, 
+                       reverse = ColRev, 
+                       ColSeq = ColSeq)
   P
 }
