@@ -11,15 +11,17 @@
 #' @param data a data table e.g. data.frame or tibble.
 #' @param ycol name of the column containing the quantitative variable whose density distribution is to be plotted.
 #' @param group name of the column containing a categorical grouping variable
-#' @param linethick thickness of symbol border, default set to 1.
+#' @param facet add another variable from the data table to create faceted graphs using \code{ggplot2}[facet_wrap].
 #' @param c_alpha fractional opacity of filled colours under the curve, default set to 0.2 (i.e. 20% opacity).
+#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
+#' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
+#' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
+#' @param linethick thickness of symbol border, default set to `fontsize`/22.
+#' @param Group deprecated old argument for `group`; retained for backward compatibility.
+#' @param alpha deprecated old argument for `c_alpha`; retained for backward compatibility.
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
-#' @param TextXAngle orientation of text on X-axis; default 0 degrees. Change to 45 or 90 to remove overlapping text.
-#' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
-#' @param Group deprecated old argument for `group`; retained for backward compatibility.
-#' @param alpha deprecated old argument for `c_alpha`; retained for backward compatibility.
 #' @param ... any additional arguments to pass to \code{ggplot2}[geom_density].
 #'
 #' @return This function returns a \code{ggplot2} object of class "gg" and "ggplot".
@@ -35,7 +37,8 @@
 #' ycol = Cholesterol, group = Treatment, 
 #' fontsize = 10)+facet_wrap("Treatment")
 
-plot_density <- function(data, ycol, group, linethick = 1, c_alpha = 0.2, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, TextXAngle = 0, fontsize = 20, Group, alpha, ...){
+plot_density <- function(data, ycol, group, facet,  c_alpha = 0.2, TextXAngle = 0, facet_scales = "fixed", fontsize = 20, linethick, Group, alpha, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, ...){
+  if(missing(linethick)) {linethick = fontsize/22}
   if (!missing("Group")) {
     warning("Use `group` argument instead, as `Group` is deprecated.")
     group <- substitute(Group)}
@@ -43,9 +46,10 @@ plot_density <- function(data, ycol, group, linethick = 1, c_alpha = 0.2, ColPal
     warning("Use `c_alpha` argument instead, as `alpha` is deprecated.")
     c_alpha <- substitute(alpha)}
   ColPal <- match.arg(ColPal)
-  P <- ggplot2::ggplot(data, aes(sample = {{ ycol }}))+
-    geom_density(size = {{ linethick }},
-                 alpha = {{ c_alpha }},
+  P <- ggplot2::ggplot(data, 
+                       aes(sample = {{ ycol }}))+
+    geom_density(size = linethick,
+                 alpha = c_alpha,
                  aes(x = {{ ycol }},
                      fill = {{ group }}, 
                      colour = {{ group }}),
@@ -53,14 +57,19 @@ plot_density <- function(data, ycol, group, linethick = 1, c_alpha = 0.2, ColPal
     labs(fill = enquo(group),
          colour = enquo(group),
          y = "Density")+
-    theme_classic(base_size = {{ fontsize }})+
+    theme_classic(base_size = fontsize)+
     theme(strip.background = element_blank())+
-    guides(x = guide_axis(angle = {{ TextXAngle }}))+
-    scale_fill_grafify(palette = {{ ColPal }}, 
-                       reverse = {{ ColRev }}, 
-                       ColSeq = {{ ColSeq }})+
-    scale_colour_grafify(palette = {{ ColPal }}, 
-                       reverse = {{ ColRev }}, 
-                       ColSeq = {{ ColSeq }})
+    guides(x = guide_axis(angle = TextXAngle))+
+    scale_fill_grafify(palette = ColPal, 
+                       reverse = ColRev, 
+                       ColSeq = ColSeq)+
+    scale_colour_grafify(palette = ColPal, 
+                         reverse = ColRev, 
+                         ColSeq = ColSeq)
+  if(!missing(facet)) {
+    P <- P + facet_wrap(vars({{ facet }}), 
+                        scales = facet_scales, 
+                        ...)
+  }
   P
 }
